"""
Modern Python Client Generator for Django Revolution

Uses openapi-python-client for excellent enum support and modern Python code.
"""

from .modern_generator import ModernPythonGenerator

__all__ = [
    "ModernPythonGenerator",
]